# Copyright (c) 2014 Dave Love, Liverpool University
# MIT licence, per Fedora policy

# fixme: unbundle pmrrr, kissfft; use unbundled metis
#        ship python stuff?
#        use ptscotch-parmetis?

%bcond_without mpich

Name:		elemental
Version:	0.85
Release:	3%{?dist}
Summary:	Distributed-memory dense linear algebra

License:	BSD
URL:		http://libelemental.org/
Source0:	http://libelemental.org/pub/releases/Elemental-%version.tgz
Patch1:		elemental-soversion.patch
# The requirements suggest this, but ut doesn't appear actually to be
# necessary.
BuildRequires:	cmake
BuildRequires:	openmpi-devel openblas-devel python-devel metis-devel
# needs to be scalapack 2
BuildRequires:	scalapack-openmpi-devel
%if 0%{?el6}
BuildRequires:	devtoolset-4-gcc-c++ devtoolset-4-binutils
BuildRequires:	devtoolset-4-gcc-gfortran
%else
BuildRequires:	gcc-gfortran
%endif
Provides:       bundled(metis)

%global desc \
Elemental is an open-source library for distributed-memory dense\
linear algebra which attempts to strike a careful balance between ease\
of use and high performance.\
\
Unique Features\
\
 * High-performance pseudospectral computation and visualization\
 * Quadratic-time low-rank Cholesky and LU modifications\
 * Bunch-Kaufman and Bunch-Parlett for accurate symmetric factorization\
 * LU and Cholesky with full pivoting\
 * Column-pivoted QR and interpolative/skeleton decompositions\
 * Quadratically Weighted Dynamic Halley iteration for the polar decomposition\
 * Spectral Divide and Conquer Schur decomposition and Hermitian EVD\
 * Many algorithms for Singular-Value soft-Thresholding (SVT)\
 * Tall-skinny QR decompositions\
 * Hermitian matrix functions\
 * Sign-based Lyapunov/Ricatti/Sylvester solvers

%description
%desc


%package openmpi
Summary:	Distributed-memory dense linear algebra - openmpi
Requires:	openmpi%{_isa}

%description openmpi
%desc

This is the openmpi version.

%package openmpi-devel
Summary:	Development files for %name-openmpi
Requires:	openmpi, %name-openmpi = %version-%release

%description openmpi-devel
Development files for %name-openmpi

%if %{with mpich}
%package mpich
Summary:	Distributed-memory dense linear algebra - mpich
BuildRequires:	scalapack-mpich-devel mpich-devel
Requires:	mpich%{_isa}

%description mpich
%desc

This is the mpich version.

%package mpich-devel
Summary:	Development files for %name-mpich
Requires:	mpich, %name-mpich = %version-%release

%description mpich-devel
Development files for %name-mpich
%endif


%prep
%setup -q -n Elemental-%version
%patch1 -p1 -b .soversion


%build

# The INSTALL_DIRs aren't being honoured
%global dobuild \
%cmake -DINCLUDE_INSTALL_DIR=$MPI_INCLUDE -DLIB_INSTALL_DIR=$MPI_LIB \\\
       -DMATH_LIBS=-lopenblas -DELEM_SHARED_LIBRARIES=yes \\\
       -DCMAKE_SKIP_RPATH=yes .. \
make %{?_smp_mflags}

%if !0%{?fedora} && 0%{?rhel} < 7
PATH=/opt/rh/devtoolset-4/root/usr/bin:$PATH
%endif
mkdir openmpi
pushd openmpi
%_openmpi_load
%dobuild
%_openmpi_unload
popd

%if %{with mpich}
mkdir mpich
pushd mpich
%_mpich_load
%dobuild
%_mpich_unload
popd
%endif


%install

%global inst \
make install DESTDIR=%buildroot\
mkdir -p %buildroot$MPI_LIB %buildroot$MPI_INCLUDE\
mv %buildroot%_prefix/lib/*.so* %buildroot$MPI_LIB\
mv %buildroot%_includedir/*.h* %buildroot$MPI_INCLUDE\
mv %buildroot%_includedir/{El,pmrrr} %buildroot$MPI_INCLUDE\
mv %buildroot%_bindir %buildroot$MPI_HOME

pushd openmpi
%_openmpi_load
%inst
%_openmpi_unload
popd

%if %{with mpich}
pushd mpich
%_mpich_load
%inst
%_mpich_unload
popd
%endif
rm -r %buildroot%_prefix/conf


%{!?_licensedir:%global license %doc}

%files openmpi
%license LICENSE
%doc AUTHORS PUBLICATIONS.bib REFERENCES.bib README.md
%_libdir/openmpi/lib/*.so.*
%_libdir/openmpi/bin/*
# fixme: do we want this installed, and is it MPI-dependent?
%exclude %python_sitelib

%files openmpi-devel
%_includedir/openmpi-%_arch/*
%_libdir/openmpi/lib/*.so

%if %{with mpich}
%files mpich
%license LICENSE
%doc AUTHORS PUBLICATIONS.bib REFERENCES.bib README.md
%_libdir/mpich/lib/*.so.*
%_libdir/mpich/bin/*

%files mpich-devel
%_includedir/mpich-%_arch/*
%_libdir/mpich/lib/*.so
%endif


%changelog
* Fri Apr 22 2016 Dave Love <loveshack@fedoraproject.org> - 0.85-3
- Fix Source0; adapt patch and install stuff
- Use devtoolset-4

* Thu Mar 17 2016 Dave Love <loveshack@fedoraproject.org> - 0.85-2
- New version

* Wed Dec 30 2015 Dave Love <loveshack@fedoraproject.org> - 0.84.1-2
- Use cmake, not cmake28
- Use devtoolset-3 on el6
- Add soversion

* Fri Oct  3 2014 Dave Love <d.love@liverpool.ac.uk> - 0.84.1-1
- Initial packaging
